==> shift-react-components-0.22.5.tgz: package/src/components/checkout/payment.js <==
// Libraries
import React, { PureComponent } from 'react'
import classNames from 'classnames'
import PropTypes from 'prop-types'

// Lib
import PaymentHeader from '../checkout/payment-header'
import StripePayment from '../checkout/stripe-payment'

export class Payment extends PureComponent {
  render () {
    const {
      addingNewAddress,
      addressBook,
      addressFormDisplayed,
      autoFillAddress,
      billingAsShipping,
      changeBillingAsShipping,
      cart,
      className,
      checkout,
      countries,
      currentAddress,
      headerTitle,
      loggedIn,
      nextStepAvailable,
      nextSection,
      onAddressDeleted,
      onBookAddressSelected,
      onBlur,
      onChange,
      onNewAddress,
      onShowField,
      onCardTokenReceived,
      setCardErrors,
      order
    } = this.props
    return (
      <div aria-label='Payment method' className={classNames(className, 'o-form c-payment')}>
        <PaymentHeader title={headerTitle}/>
        <div className='c-payment__section' style={{ display: 'block' }}>
          <StripePayment
            addingNewAddress={addingNewAddress}
            addressBook={addressBook}
            addressFormDisplayed={addressFormDisplayed}
            autoFillAddress={autoFillAddress}
            billingAddress={cart.billing_address}
            billingAsShipping={billingAsShipping}
            cardTokenRequested={order.cardTokenRequested}
            changeBillingAsShipping={changeBillingAsShipping}
            checkout={checkout}
            currentAddress={currentAddress}
            countries={countries}
            loggedIn={loggedIn}
            nextStepAvailable={nextStepAvailable}
            nextSection={nextSection}
            onAddressDeleted={onAddressDeleted}
            onBookAddressSelected={onBookAddressSelected}
            onBlur={onBlur}
            onChange={onChange}
            onNewAddress={onNewAddress}
            onShowField={onShowField}
            onCardTokenReceived={onCardTokenReceived}
            setCardErrors={setCardErrors}
            shippingAddress={cart.shipping_address}
          />
        </div>
      </div>
    )
  }
}

Payment.propTypes = {
  addingNewAddress: PropTypes.bool,
  addressBook: PropTypes.array,
  addressFormDisplayed: PropTypes.func,
  autoFillAddress: PropTypes.func,
  billingAsShipping: PropTypes.bool,
  changeBillingAsShipping: PropTypes.func,
  cart: PropTypes.object,
  className: PropTypes.string,
  checkout: PropTypes.object,
  countries: PropTypes.array,
  currentAddress: PropTypes.object,
  headerTitle: PropTypes.string.isRequired,
  loggedIn: PropTypes.bool,
  nextStepAvailable: PropTypes.func,
  nextSection: PropTypes.func,
  onAddressDeleted: PropTypes.func,
  onBookAddressSelected: PropTypes.func,
  onBlur: PropTypes.func,
  onChange: PropTypes.func,
  onNewAddress: PropTypes.func,
  onShowField: PropTypes.func,
  onCardTokenReceived: PropTypes.func,
  order: PropTypes.object,
  setCardErrors: PropTypes.func
}

==> shift-react-components-0.22.29.tgz: package/src/components/checkout/payment.js <==
// Libraries
import React, { PureComponent } from 'react'
import classNames from 'classnames'
import PropTypes from 'prop-types'

// Lib
import PaymentHeader from '../checkout/payment-header'
import StripePayment from '../checkout/stripe-payment'

export class Payment extends PureComponent {
  render () {
    const {
      addingNewAddress,
      addressBook,
      addressFormDisplayed,
      autoFillAddress,
      billingAsShipping,
      changeBillingAsShipping,
      cart,
      className,
      checkout,
      countries,
      currentAddress,
      headerTitle,
      loggedIn,
      nextStepAvailable,
      nextSection,
      onAddressDeleted,
      onBookAddressSelected,
      onBlur,
      onChange,
      onNewAddress,
      onShowField,
      onPaymentMethodCreate,
      setCardErrors,
      confirmPaymentIntent,
      order
    } = this.props
    return (
      <div aria-label='Payment method' className={classNames(className, 'o-form c-payment')}>
        <PaymentHeader title={headerTitle}/>
        <div className='c-payment__section' style={{ display: 'block' }}>
          <StripePayment
            addingNewAddress={addingNewAddress}
            addressBook={addressBook}
            addressFormDisplayed={addressFormDisplayed}
            autoFillAddress={autoFillAddress}
            billingAddress={cart.billing_address}
            billingAsShipping={billingAsShipping}
            cardTokenRequested={order.cardTokenRequested}
            changeBillingAsShipping={changeBillingAsShipping}
            checkout={checkout}
            currentAddress={currentAddress}
            countries={countries}
            loggedIn={loggedIn}
            nextStepAvailable={nextStepAvailable}
            nextSection={nextSection}
            onAddressDeleted={onAddressDeleted}
            onBookAddressSelected={onBookAddressSelected}
            onBlur={onBlur}
            onChange={onChange}
            onNewAddress={onNewAddress}
            onShowField={onShowField}
            onPaymentMethodCreate={onPaymentMethodCreate}
            setCardErrors={setCardErrors}
            confirmPaymentIntent={confirmPaymentIntent}
            shippingAddress={cart.shipping_address}
            paymentIntent={order.paymentIntent}
          />
        </div>
      </div>
    )
  }
}

Payment.propTypes = {
  addingNewAddress: PropTypes.bool,
  addressBook: PropTypes.array,
  addressFormDisplayed: PropTypes.func,
  autoFillAddress: PropTypes.func,
  billingAsShipping: PropTypes.bool,
  changeBillingAsShipping: PropTypes.func,
  cart: PropTypes.object,
  className: PropTypes.string,
  checkout: PropTypes.object,
  countries: PropTypes.array,
  currentAddress: PropTypes.object,
  headerTitle: PropTypes.string.isRequired,
  loggedIn: PropTypes.bool,
  nextStepAvailable: PropTypes.func,
  nextSection: PropTypes.func,
  onAddressDeleted: PropTypes.func,
  onBookAddressSelected: PropTypes.func,
  onBlur: PropTypes.func,
  onChange: PropTypes.func,
  onNewAddress: PropTypes.func,
  onShowField: PropTypes.func,
  onPaymentMethodCreate: PropTypes.func,
  order: PropTypes.object,
  setCardErrors: PropTypes.func
}
